﻿using Composite.Data.Plugins.DataProvider;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration.ObjectBuilder;
using Microsoft.Practices.ObjectBuilder;

namespace Sample.DataProvider.CultureData
{
    /// <summary>
    /// This is the 'configuration class' for our provider - this enable us to create custom config values
    /// that a sysadmin or dev can change in Composite.config, this controlling our behaviour. 
    /// Here we keep it simple and have no custom config.
    /// The Assembler attribute points to the Factory that - given this config - can assemble our data provider, see class below.
    /// </summary>
    [Assembler(typeof(CultureDataProviderAssembler))]
    internal sealed class CultureDataProviderConfigData : DataProviderData
    {
    }

    /// <summary>
    /// Here we are handed our configuration and are tasked with constructing our 'CultureDataProvider' - Composite C1 gets your provider from here.
    /// This is only called once, when the system start up - your provider is a singleton that lives untill the app shut down.
    /// </summary>
    internal sealed class CultureDataProviderAssembler : IAssembler<IDataProvider, DataProviderData>
    {
        public IDataProvider Assemble(IBuilderContext context, DataProviderData configData, IConfigurationSource configurationSource, ConfigurationReflectionCache reflectionCache)
        {
            return new CultureDataProvider();
        }
    }
}
